<?php
use PrestaShop\PrestaShop\Adapter\Entity\Db;
use PrestaShop\PrestaShop\Adapter\Entity\Order;

if (!defined('_PS_VERSION_')) {
    exit;
}

class EcontDelivery extends CarrierModule {

    public function __construct() {
        $this->name = 'econtdelivery';
        $this->tab = 'shipping_logistics';
        $this->version = '1.1.2';
        $this->author = 'IT Partner';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Достави с Еконт');
        $this->description = $this->l('Модул за доставка с Еконт Експрес.');

        if (!Configuration::get('ECONT_DELIVERY')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install() {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }

        if (!parent::install()) {
            return false;
        }

        //actionCarrierUpdate

        $carrier = new Carrier();
        $carrier->name = "Еконт Експрес";
        $carrier->active = TRUE;
        $carrier->deleted = 0;
        $carrier->url = 'https://www.econt.com/services/track-shipment/@';
        $carrier->shipping_handling = FALSE;
        $carrier->range_behavior = 0;
        $carrier->delay[Configuration::get('PS_LANG_DEFAULT')] = 'един работен ден';
        $carrier->shipping_external = TRUE;
        $carrier->is_module = TRUE;
        $carrier->external_module_name = $this->name;
        $carrier->need_range = TRUE;

        $econtDeliveryOrderInfoTable = _DB_PREFIX_.'econt_delivery_order_info';
        $engine = _MYSQL_ENGINE_;
        Db::getInstance()->execute("
            CREATE TABLE IF NOT EXISTS `$econtDeliveryOrderInfoTable` (
                `id_order` INT(10) UNSIGNED NOT NULL,
                `info` MEDIUMTEXT NOT NULL,
                PRIMARY KEY (`id_order`)
            )
            ENGINE=$engine
        ");

        if ($carrier->add()) {
            $groups = Group::getGroups(true);
            foreach ($groups as $group) {
                Db::getInstance()->insert('carrier_group',array(
                    'id_carrier' => (int) $carrier->id,
                    'id_group' => (int) $group['id_group']
                ));
            }

            $rangePrice = new RangePrice();
            $rangePrice->id_carrier = $carrier->id;
            $rangePrice->delimiter1 = '0';
            $rangePrice->delimiter2 = '1000000';
            $rangePrice->add();

            $rangeWeight = new RangeWeight();
            $rangeWeight->id_carrier = $carrier->id;
            $rangeWeight->delimiter1 = '0';
            $rangeWeight->delimiter2 = '1000000';
            $rangeWeight->add();

            $zones = Zone::getZones(true);
            foreach ($zones as $z) {
                Db::getInstance()->insert('carrier_zone', array('id_carrier' => (int) $carrier->id, 'id_zone' => (int) $z['id_zone']));
                Db::getInstance()->insert('delivery', array('id_carrier' => $carrier->id, 'id_range_price' => (int) $rangePrice->id, 'id_range_weight' => NULL, 'id_zone' => (int) $z['id_zone'], 'price' => '0'), true);
                Db::getInstance()->insert('delivery', array('id_carrier' => $carrier->id, 'id_range_price' => NULL, 'id_range_weight' => (int) $rangeWeight->id, 'id_zone' => (int) $z['id_zone'], 'price' => '0'), true);
            }

            copy(dirname(__FILE__) . '/carrier-logo.jpg', _PS_SHIP_IMG_DIR_ . '/' . (int) $carrier->id . '.jpg'); //assign carrier logo

            Configuration::updateValue('ECONT_DELIVERY_CARRIER_ID', $carrier->id);
            Configuration::updateValue('ECONT_DELIVERY_CARRIER_ID_REF', $carrier->id);
        }

        if(!$this->registerHook('actionCarrierUpdate')) return false;
        if(!$this->registerHook('displayCarrierExtraContent')) return false;
        if(!$this->registerHook('actionDispatcherBefore')) return false;
        if(!$this->registerHook('displayShoppingCart')) return false;
        if(!$this->registerHook('displayCheckoutSubtotalDetails')) return false;
        if(!$this->registerHook('displayCheckoutSummaryTop')) return false;
        if(!$this->registerHook('actionValidateOrder')) return false;
        if(!$this->registerHook('actionOrderStatusPostUpdate')) return false;
        if(!$this->registerHook('displayAdminOrderTabShip')) return false;
        if(!$this->registerHook('actionBeforeCartUpdateQty')) return false;

        return true;
    }

    public function uninstall() {
        if (!parent::uninstall()) {
            return false;
        }

        $carrier = new Carrier(Configuration::get('ECONT_DELIVERY_CARRIER_ID'));
        $carrier->delete();

        if(!$this->unregisterHook('actionCarrierUpdate')) return false;
        if(!$this->unregisterHook('displayCarrierExtraContent')) return false;
        if(!$this->unregisterHook('actionDispatcherBefore')) return false;
        if(!$this->unregisterHook('displayShoppingCart')) return false;
        if(!$this->unregisterHook('displayCheckoutSubtotalDetails')) return false;
        if(!$this->unregisterHook('displayCheckoutSummaryTop')) return false;
        if(!$this->unregisterHook('actionValidateOrder')) return false;
        if(!$this->unregisterHook('actionOrderStatusPostUpdate')) return false;
        if(!$this->unregisterHook('displayAdminOrderTabShip')) return false;
        if(!$this->unregisterHook('actionCartUpdateQuantityBefore')) return false;

        return true;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('submitEcontDeliverySettings')) {

            $endpoint = Tools::getValue('ECONT_DELIVERY_ENDPOINT');
            $secret = Tools::getValue('ECONT_DELIVERY_SECRET');

            $curl = curl_init();
            curl_setopt($curl, CURLOPT_URL, $endpoint."/services/OrdersService.getTrace.json");
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($curl, CURLOPT_HTTPHEADER, [
                'Content-Type: application/json',
                "Authorization: ".$secret
            ]);
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode(array(
                'orderNumber' => 4812384
            )));
            curl_setopt($curl, CURLOPT_TIMEOUT, 6);
            $res = curl_exec($curl);
            $response = json_decode($res, true);

            curl_close($curl);

            if(is_array($response) && $response['type'] == 'ExAccessDenied') {
                $output .=  $this->displayError($this->l("Кода за свързване не е коректен."));
            } else {
                Configuration::updateValue('ECONT_DELIVERY_ENDPOINT', $endpoint);
                Configuration::updateValue('ECONT_DELIVERY_SECRET', $secret);
                $output .= $this->displayConfirmation($this->trans('Settings updated.', array(), 'Admin.Notifications.Success'));
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name);
            }
        }

        $helper = new HelperForm();
        $helper->submit_action = 'submitEcontDeliverySettings';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => array(
                'ECONT_DELIVERY_ENDPOINT' => Configuration::get('ECONT_DELIVERY_ENDPOINT'),
                'ECONT_DELIVERY_SECRET' => Configuration::get('ECONT_DELIVERY_SECRET'),
            )
        );

        return $output.$helper->generateForm(array(
            array(
                'form' => array(
                    'legend' => array(
                        'title' => $this->displayName,
                        'icon' => 'icon-share'
                    ),
                    'input' => array(
                        array(
                            'type' => 'select',
                            'name' => 'ECONT_DELIVERY_ENDPOINT',
                            'label' => $this->l("Среда"),
                            'options' => array(
                                'query' => array(
                                    array(
                                        'idq' => 'https://delivery.econt.com',
                                        'name' => $this->l('Реална'),
                                    ),
                                    array(
                                        'idq' => 'http://delivery.demo.econt.com',
                                        'name' => $this->l('Тестова'),
                                    ),
                                ),
                                'id' => 'idq',
                                'name' => 'name'
                            )
                        ),
                        array(
                            'type' => 'password',
                            'name' => 'ECONT_DELIVERY_SECRET',
                            'label' => $this->l("Код за свързване"),
                            'maxlength' => 100
                        ),
                    ),
                    'submit' => array(
                        'title' => $this->trans('Save', array(), 'Admin.Actions')
                    )
                )
            )
        ));
    }

    public function hookActionCarrierUpdate($params)
    {
        if ($params['carrier']->id_reference == Configuration::get('ECONT_DELIVERY_CARRIER_ID_REF')) {
            Configuration::updateValue('ECONT_DELIVERY_CARRIER_ID', $params['carrier']->id);
        }
    }

    public function hookActionCartUpdateQuantityBefore($params)
    {
        $this->context->cookie->{"econt_delivery_info-".$params['cart']->id} = null;
    }

    public function hookActionValidateOrder($params) {
        if((intval($params['order']->id)) && ($econtDeliveryInfo = json_decode($this->context->cookie->{"econt_delivery_info-".$params['cart']->id},true))) {
            Db::getInstance()->insert('econt_delivery_order_info',array(
                'id_order' => (int) $params['order']->id,
                'info' => Db::getInstance()->escape(json_encode($econtDeliveryInfo, JSON_PRETTY_PRINT|JSON_UNESCAPED_UNICODE))
            ),false,false,Db::REPLACE);
            $this->context->cookie->{"econt_delivery_info-".$params['cart']->id} = null;
        }
    }

    public function hookActionOrderStatusPostUpdate($params) {
        $this->syncOrder($params['id_order']);
    }

    public function hookDisplayCheckoutSummaryTop($params)
    {
        if($params['smarty'] && round($params['smarty']->tpl_vars['cart']->value['subtotals']['shipping']['amount'],2) == 0) {
            $params['smarty']->tpl_vars['cart']->value['subtotals']['shipping'] = null;
        }
    }

    public function hookDisplayShoppingCart($params) {
        if($params['smarty'] && round($params['smarty']->tpl_vars['cart']->value['subtotals']['shipping']['amount'],2) == 0) {
            $params['smarty']->tpl_vars['cart']->value['subtotals']['shipping'] = null;
        }
    }

    public function hookDisplayCheckoutSubtotalDetails($params) {
        if($params['smarty'] && round($params['smarty']->tpl_vars['cart']->value['subtotals']['shipping']['amount'],2) == 0) {
            $params['smarty']->tpl_vars['cart']->value['subtotals']['shipping'] = null;
        }
    }

    public function hookActionDispatcherBefore($a) {
        if(isset($_REQUEST['confirmDeliveryOption']) && $_REQUEST['confirmDeliveryOption'] && $econtDeliveryInfo = json_decode($_REQUEST['econt_delivery_info'],true)) {
            $this->context->cookie->{"econt_delivery_info-".$this->context->cookie->id_cart} = $_REQUEST['econt_delivery_info'];
        }
        if(isset($_REQUEST['controller']) && $_REQUEST['controller'] == 'AdminOrders' && isset($_REQUEST['submitAddressShipping']) && !empty($_REQUEST['id_order']) && !empty($_REQUEST['econt_delivery_customer_info'])) {
            Db::getInstance()->insert('econt_delivery_order_info',array(
                'id_order' => $_REQUEST['id_order'],
                'info' => Db::getInstance()->escape($_REQUEST['econt_delivery_customer_info']),
            ),false,false,Db::REPLACE);
            $this->syncOrder($_REQUEST['id_order']);
        }
    }

    public function hookDisplayAdminOrderTabShip($params) {
        if($params['order']->id_carrier != Configuration::get('ECONT_DELIVERY_CARRIER_ID')) return '';
        /** @var Order $order */
        $order = $params['order'];


        if(!($order->id && ($deliveryBaseURL = Configuration::get('ECONT_DELIVERY_ENDPOINT')) && ($deliverySecret = Configuration::get('ECONT_DELIVERY_SECRET')))) return '';
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, "{$deliveryBaseURL}/services/OrdersService.getTrace.json");
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($curl, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            "Authorization: {$deliverySecret}"
        ]);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode(array(
            'orderNumber' => $order->id
        )));
        curl_setopt($curl, CURLOPT_TIMEOUT, 6);
        $response = json_decode(curl_exec($curl), true);
        $responseInfo = curl_getinfo($curl);
        if ($responseInfo['http_code'] !== 200) $response['error'] = $response;
        curl_close($curl);

        if(!$response['error']) {
            if($order->shipping_number != $response['shipmentNumber']) {
                $order->setWsShippingNumber($response['shipmentNumber']);
                $order->shipping_number = $response['shipmentNumber'];
                $order->update();
            }
        }
        $customer = $order->getCustomer();
        $address = new Address($order->id_address_delivery);
        $currency = $this->context->currency->id == $order->id_currency ? $this->context->currency : Currency::getCurrency($order->id_currency);
        if($address->id_country) {
            $countryCode = Country::getIsoById($address->id_country);
        } else {
            $countryCode = $this->context->country->iso_code;
        }

        @$customerInfoParams = array(
            'id_shop' => intval(@reset(explode('@',Configuration::get('ECONT_DELIVERY_SECRET')))),
            'order_weight' => $order->getTotalWeight(),
            'order_total' => $order->getTotalProductsWithTaxes(),
            'order_currency' => $currency->iso_code,
            'customer_company' => $customer->company,
            'customer_name' => "{$customer->firstname} {$customer->lastname}",
            'customer_email' => $customer->email,
            'customer_phone' =>  $address->phone ? $address->phone : $address->phone_mobile,
            'customer_country' => $countryCode,
            'customer_city_name' => $address->city,
            'customer_post_code' => $address->postcode,
            'customer_address' => $address->address1.' '.$address->address2,
            'ignore_history' => 1,
            'default_css' => 1
        );

        $prepareLoadingFrameURL = $deliveryBaseURL. '/create_label.php?' . http_build_query(array('order_number' => $order->id, 'token' => $deliverySecret));
        $customerInfoFrameURL = $deliveryBaseURL.'/customer_info.php?'.http_build_query($customerInfoParams,null,'&');

        ob_start();?>
        <script>
            document.addEventListener("DOMContentLoaded", function() {
                $(document.body).delegate('a','click',function(e){
                    if(this.href.indexOf('generateDeliverySlipPDF') > 0) {
                        var num = $('.shipping_number_show').text().trim();
                        if(num) {
                            window.open(<?php echo json_encode($response['pdfURL']);?>);
                        } else {
                            $('<a href="<?php echo $prepareLoadingFrameURL?>">bla</a>').appendTo(document.body).fancybox({width:700,height:'100%',type:'iframe',title:''}).trigger('click').remove()
                        }
                        e.preventDefault();
                    }
                });

                var $editDeliveryBtn = $('<button class="btn btn-default changeEcontAddress" type="button""></button>').html('<i class="icon-truck"></i> Промяна на данните за доставка');
                $('select[name=id_address]').after($editDeliveryBtn).after($("<br/>"));

                $(".changeEcontAddress").click(function(){
                    console.log(1234);
                    $('<a href="<?php echo $customerInfoFrameURL?>">bla</a>').appendTo(document.body).fancybox({width:550,height:630,type:'iframe',title:''}).trigger('click').remove()
                });

                $(window).unbind('message.econtShipping');
                $(window).bind('message.econtShipping',function(e){
                    if(e.originalEvent.origin.indexOf('<?php echo $deliveryBaseURL?>') == 0) {
                        var messageData = e['originalEvent']['data'];
                        if (!messageData) return;

                        if(messageData['event'] == 'cancel') {
                            $('.fancybox-close').trigger('click');
                        } else if(messageData['event'] == 'confirm') {
                            if (messageData['printPdf'] === true && messageData['shipmentStatus']['pdfURL']) window.open(messageData['shipmentStatus']['pdfURL'], '_blank');
                            $('.fancybox-close').trigger('click');
                            window.location.href = window.location.href;
                        } else if(!messageData['event']) {
                            if(messageData['shipment_error']) {
                                alert(messageData['shipment_error']);
                            } else {
                                var $changeDeliveryBtn = $('.btn.btn-default[name=submitAddressShipping]');
                                $('<input type="hidden" name="econt_delivery_customer_info" />').appendTo($changeDeliveryBtn.parent()).val(JSON.stringify(messageData));
                                $('.fancybox-close').trigger('click');
                                $changeDeliveryBtn.trigger('click');
                            }
                        }
                        //console.log(messageData);
                    }
                });
            });
        </script>
        <?php
        return ob_get_clean();
    }

    public function hookActionAdminGenerateDeliverySlipPDFBefore() {
        if(!empty($_REQUEST['id_order']) && !($orderID = intval($_REQUEST['id_order']))) return;
        $pref = _DB_PREFIX_;
        $orderData = Db::getInstance()->getRow("
            SELECT 
                o.id,
                i.info as econt_delivery_info,
                o.id_carrier
            FROM {$pref}orders o
            JOIN {$pref}econt_delivery_order_info i ON i.id_order = o.id_order
            WHERE o.id_order = $orderID
        ",false);
        if(empty($orderData) || $orderData['id_carrier'] != Configuration::get('ECONT_DELIVERY_CARRIER_ID')) return;

    }

    public function hookDisplayCarrierExtraContent() {
        $address = new Address(intval($this->context->cart->id_address_delivery));
        if($address->id_country) {
            $countryCode = Country::getIsoById($address->id_country);
        } else {
            $countryCode = $this->context->country->iso_code;
        }
        
        @$frameParams = array(
            'id_shop' => intval(@reset(explode('@',Configuration::get('ECONT_DELIVERY_SECRET')))),
            'order_weight' => $this->context->cart->getTotalWeight(),
            'order_total' => $this->context->cart->getOrderTotal(),
            'order_currency' => $this->context->currency->iso_code,
            'customer_company' => $this->context->customer->company,
            'customer_name' => "{$this->context->customer->firstname} {$this->context->customer->lastname}",
            'customer_email' => $this->context->customer->email,
            'customer_phone' =>  $address->phone ? $address->phone : $address->phone_mobile,
            'customer_country' => $countryCode,
            'customer_city_name' => $address->city,
            'customer_post_code' => $address->postcode,
            'customer_address' => $address->address1.' '.$address->address2,
        );

        $deliveryBaseURL = Configuration::get('ECONT_DELIVERY_ENDPOINT');
        $frameURL = $deliveryBaseURL.'/customer_info.php?'.http_build_query($frameParams,null,'&');
        $deliveryMethodPriceCD = $this->l('наложен платеж');

        ob_start();?>
        <iframe id="econt_delivery_customer_info_frame" style="width:100%;height:612px;border:none;margin-top: 15px;" src="<?php echo $frameURL?>"></iframe>
        <input type="hidden" id="econt_delivery_info" name="econt_delivery_info">
        <script>
            document.addEventListener("DOMContentLoaded", function(event) {
                var $hiddenInput = $('#econt_delivery_info');
                var shippingInfo = null;
                var $frame = $('#econt_delivery_customer_info_frame');
                var $econtRadio = $('.delivery-options input:radio').filter(function(i,el){return parseInt(el.value) == <?php echo Configuration::get('ECONT_DELIVERY_CARRIER_ID')?>;});
                var $confirmBtn = $('.continue[name=confirmDeliveryOption]');
                $econtRadio.parents('.delivery-option').find('.carrier-price').text('---');
                $('.delivery-options .custom-radio span').click(function(e){
                    var inp = $(this).siblings('input')[0];
                    if(parseInt(inp.value) == <?php echo Configuration::get('ECONT_DELIVERY_CARRIER_ID')?>) {
                        $frame.parent().show();
                        $confirmBtn.attr({disabled:true});
                    } else {
                        $frame.parent().hide();
                        $confirmBtn.attr({disabled:false});
                    }
                });
                $('.delivery-options input:radio').change(function(e){
                    e.stopPropagation();
                    if(parseInt(this.value) == <?php echo Configuration::get('ECONT_DELIVERY_CARRIER_ID')?>) {
                        $frame.parent().show();
                        $confirmBtn.attr({disabled:true});
                    } else {
                        $frame.parent().hide();
                        $confirmBtn.attr({disabled:false});
                    }
                });
                $('.delivery-options input:radio:checked').each(function(){
                    if(parseInt(this.value) == <?php echo Configuration::get('ECONT_DELIVERY_CARRIER_ID')?>) {
                        $econtRadio = $(this);
                        $frame.parent().show();
                        $confirmBtn.attr({disabled:true});
                    }
                });
                $(window).unbind('message.econtShipping');
                $(window).bind('message.econtShipping',function(e){
                    if(e.originalEvent.origin.indexOf('<?php echo $deliveryBaseURL?>') == 0) {
                        if(e.originalEvent.data.shipment_error) {
                            alert(e.originalEvent.data.shipment_error)
                        } else {
                            shippingInfo = e.originalEvent.data;
                            $frame.parent().hide();
                            $confirmBtn.attr({disabled:false});
                            //console.log(shippingInfo);
                            var labelTxt = shippingInfo.shipping_price + shippingInfo.shipping_price_currency_sign;
                            if(shippingInfo.shipping_price != shippingInfo.shipping_price_cod) {
                                labelTxt += ' (+ ' + (shippingInfo.shipping_price_cod - shippingInfo.shipping_price).toFixed(2) + shippingInfo.shipping_price_currency_sign + ' ' + <?php echo json_encode($deliveryMethodPriceCD)?> + ')'
                            }
                            $econtRadio.parents('.delivery-option').find('.carrier-price').text(labelTxt);
                            $hiddenInput.val(JSON.stringify(e.originalEvent.data));
                        }
                    }
                });
            });
        </script>
<?php
        return ob_get_clean();
    }

    public function getOrderShippingCost($cart, $shipping_cost) {
        $order = null;
        if($cart->id) $order = Order::getByCartId($cart->id);
        if(!$order && !empty($_REQUEST['id_order'])) $order = new Order($_REQUEST['id_order']);

        if($orderID = intval($order->id)) {
            $row = Db::getInstance()->getRow("SELECT * FROM econt_delivery_order_info WHERE id_order = $orderID");
            $econtDeliveryInfo = json_decode($row['info'],true);
            return ($order->module == 'ps_cashondelivery' ? $econtDeliveryInfo['shipping_price_cod'] : $econtDeliveryInfo['shipping_price']);
        } else if($this->context->cookie->{"econt_delivery_info-".$cart->id}){
            if($econtDeliveryInfo = json_decode($this->context->cookie->{"econt_delivery_info-".$cart->id},true)) {
                return get_class($this->context->controller) == 'Ps_CashondeliveryValidationModuleFrontController' ? $econtDeliveryInfo['shipping_price_cod'] : $econtDeliveryInfo['shipping_price'];
            }
            return 0;
        } else {
            return 0;
        }
    }

    public function getOrderShippingCostExternal($params) {
        return $this->getOrderShippingCost($params, 0);
    }

    public function syncOrder($orderID) {

        if(!($deliveryBaseURL = Configuration::get('ECONT_DELIVERY_ENDPOINT'))) return;
        if(!($deliverySecret = Configuration::get('ECONT_DELIVERY_SECRET'))) return;

        if(!($orderID = intval($orderID))) return;
        $pref = _DB_PREFIX_;
        $defLangID = Configuration::get('PS_LANG_DEFAULT');
        $orderData = Db::getInstance()->getRow("
            SELECT 
                o.*,
                i.info as econt_delivery_info,
                osl.name as order_status,
                cr.iso_code as currency_code
            FROM {$pref}orders o
            JOIN {$pref}cart c ON c.id_cart = o.id_cart
            JOIN {$pref}econt_delivery_order_info i ON i.id_order = o.id_order
            JOIN (SELECT id_lang FROM {$pref}lang ORDER BY id_lang = $defLangID DESC LIMIT 1) as dl
            JOIN {$pref}order_state_lang osl ON osl.id_order_state = o.current_state AND osl.id_lang = dl.id_lang
            JOIN {$pref}currency cr ON cr.id_currency = o.id_currency
            WHERE o.id_order = $orderID
        ",false);

        if(empty($orderData) || $orderData['id_carrier'] != Configuration::get('ECONT_DELIVERY_CARRIER_ID')) return;

        $customerInfo = json_decode($orderData['econt_delivery_info'],true);
        if (!$customerInfo || empty($customerInfo['id'])) return;

        $o = new Order($orderID);

        $order = array(
            'customerInfo' => array(
                'id' => $customerInfo['id']
            ),
            'orderNumber' => $orderData['id_order'],
            'shipmentDescription' => sprintf("Order #{$orderData['id_order']}"),
            'status' => $orderData['order_status'],
            'orderTime' => $orderData['date_add'],
            'currency' => $orderData['currency_code'],
            'cod' => ($orderData['module'] === 'ps_cashondelivery'),
            'partialDelivery' => 1,
            'items' => array()
        );

        $link = new Link();

        $d = $o->total_products_wt + $o->total_wrapping_tax_incl - $o->total_discounts_tax_incl;

        foreach($o->getProducts() as $product) {
            $order['items'][] = array(
                'name' => $product['product_name'],
                'SKU' => $product['reference'],
                'URL' => $link->getProductLink($product['product_id']),
                'count' =>$product['product_quantity'],
                'totalPrice' => $product['total_price_tax_incl'],
                'totalWeight' => $product['product_weight'] * $product['product_quantity']
            );
            $d -= $product['total_price_tax_incl'];
        };

        if(round($d,2) != 0) {
            $order['items'][] = array(
                'name' => 'Отстъпка',
                'SKU' => '',
                'URL' => '',
                'count' => 1,
                'totalPrice' => $d,
                'totalWeight' => 0
            );
            $order['partialDelivery'] = 0;
        }

        try {
            $curl = curl_init();
            curl_setopt($curl, CURLOPT_URL, "{$deliveryBaseURL}/services/OrdersService.updateOrder.json");
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($curl, CURLOPT_HTTPHEADER, [
                'Content-Type: application/json',
                "Authorization: {$deliverySecret}"
            ]);
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($order));
            curl_setopt($curl, CURLOPT_TIMEOUT, 6);
            $response = curl_exec($curl);
            curl_close($curl);
        } catch (Exception $exception) {
            //$logger = new Log('econt_delivery.log');
            //$logger->write(sprintf('Curl failed with error [%d] %s', $exception->getCode(), $exception->getMessage()));
        }
    }
}